@@ -24,6 +24,7 @@ from IPython.testing.skipdoctest import skip_doctest
 from IPython.utils.openpy import source_to_unicode
 from IPython.utils.process import abbrev_cwd
 from IPython.utils.terminal import set_term_title
+from traitlets import Bool
 
 
 @magics_class
@@ -31,6 +32,10 @@ class OSMagics(Magics):
     """Magics to interact with the underlying OS (shell-type functionality).
     """
 
+    cd_force_quiet = Bool(False,
+        help="Force %cd magic to be quiet even if -q is not passed."
+    ).tag(config=True)
+
     def __init__(self, shell=None, **kwargs):
 
         # Now define isexec in a cross platform manner.
@@ -414,7 +419,7 @@ class OSMagics(Magics):
             if oldcwd != cwd:
                 dhist.append(cwd)
                 self.shell.db['dhist'] = compress_dhist(dhist)[-100:]
-        if not 'q' in opts and self.shell.user_ns['_dh']:
+        if not 'q' in opts and not self.cd_force_quiet and self.shell.user_ns['_dh']:
             print(self.shell.user_ns['_dh'][-1])
 
     @line_magic
