@@ -22,7 +22,7 @@ import os
 from textwrap import dedent
 import types
 import io as stdlib_io
-from itertools import zip_longest 
+from itertools import zip_longest
 
 # IPython's own
 from IPython.core import page
@@ -203,7 +203,7 @@ def is_simple_callable(obj):
 def getargspec(obj):
     """Wrapper around :func:`inspect.getfullargspec` on Python 3, and
     :func:inspect.getargspec` on Python 2.
-    
+
     In addition to functions and methods, this can also handle objects with a
     ``__call__`` attribute.
     """
@@ -327,7 +327,7 @@ def find_source_lines(obj):
       The line number where the object definition starts.
     """
     obj = _get_wrapped(obj)
-    
+
     try:
         try:
             lineno = inspect.getsourcelines(obj)[1]
@@ -362,7 +362,7 @@ class Inspector(Colorable):
         If any exception is generated, None is returned instead and the
         exception is suppressed."""
         try:
-            hdef = oname + str(signature(obj))
+            hdef = _render_signature(signature(obj), oname)
             return cast_unicode(hdef)
         except:
             return None
@@ -582,7 +582,7 @@ class Inspector(Colorable):
 
     def _get_info(self, obj, oname='', formatter=None, info=None, detail_level=0):
         """Retrieve an info dict and format it.
-        
+
         Parameters
         ==========
 
@@ -639,6 +639,7 @@ class Inspector(Colorable):
 
             append_field(_mime, 'File', 'file')
             append_field(_mime, 'Type', 'type_name')
+            append_field(_mime, 'Subclasses', 'subclasses')
 
         else:
             # General Python objects
@@ -653,7 +654,7 @@ class Inspector(Colorable):
 
             append_field(_mime, 'Length', 'length')
             append_field(_mime, 'File', 'file')
-            
+
             # Source or docstring, depending on detail level and whether
             # source found.
             if detail_level > 0 and info['source']:
@@ -664,7 +665,7 @@ class Inspector(Colorable):
             append_field(_mime, 'Class docstring', 'class_docstring', formatter)
             append_field(_mime, 'Init docstring', 'init_docstring', formatter)
             append_field(_mime, 'Call docstring', 'call_docstring', formatter)
-            
+
 
         return self.format_mime(_mime)
 
@@ -752,7 +753,7 @@ class Inspector(Colorable):
                 ds = '<no docstring>'
 
         # store output in a dict, we initialize it here and fill it as we go
-        out = dict(name=oname, found=True, isalias=isalias, ismagic=ismagic)
+        out = dict(name=oname, found=True, isalias=isalias, ismagic=ismagic, subclasses=None)
 
         string_max = 200 # max size of strings to show (snipped if longer)
         shalf = int((string_max - 5) / 2)
@@ -859,6 +860,12 @@ class Inspector(Colorable):
             if init_ds:
                 out['init_docstring'] = init_ds
 
+            names = [sub.__name__ for sub in obj.__subclasses__()]
+            if len(names) < 10:
+                all_names = ', '.join(names)
+            else:
+                all_names = ', '.join(names[:10]+['...'])
+            out['subclasses'] = all_names
         # and class docstring for instances:
         else:
             # reconstruct the function definition and print it:
@@ -1012,3 +1019,44 @@ class Inspector(Colorable):
             search_result.update(tmp_res)
 
         page.page('\n'.join(sorted(search_result)))
+
+
+def _render_signature(obj_signature, obj_name):
+    """
+    This was mostly taken from inspect.Signature.__str__.
+    Look there for the comments.
+    The only change is to add linebreaks when this gets too long.
+    """
+    result = []
+    pos_only = False
+    kw_only = True
+    for param in obj_signature.parameters.values():
+        if param.kind == inspect._POSITIONAL_ONLY:
+            pos_only = True
+        elif pos_only:
+            result.append('/')
+            pos_only = False
+
+        if param.kind == inspect._VAR_POSITIONAL:
+            kw_only = False
+        elif param.kind == inspect._KEYWORD_ONLY and kw_only:
+            result.append('*')
+            kw_only = False
+
+        result.append(str(param))
+
+    if pos_only:
+        result.append('/')
+
+    # add up name, parameters, braces (2), and commas
+    if len(obj_name) + sum(len(r) + 2 for r in result) > 75:
+        # This doesn’t fit behind “Signature: ” in an inspect window.
+        rendered = '{}(\n{})'.format(obj_name, ''.join('    {},\n'.format(result)))
+    else:
+        rendered = '{}({})'.format(obj_name, ', '.join(result))
+
+    if obj_signature.return_annotation is not inspect._empty:
+        anno = inspect.formatannotation(obj_signature.return_annotation)
+        rendered += ' -> {}'.format(anno)
+
+    return rendered
