@@ -34,7 +34,6 @@ from IPython.core.profiledir import ProfileDir
 
 from IPython.testing import decorators as dec
 from IPython.testing import tools as tt
-from IPython.utils import py3compat
 from IPython.utils.process import getoutput
 from IPython.utils.tempdir import TemporaryDirectory
 
@@ -100,15 +99,14 @@ class ProfileStartupTest(TestCase):
             f.write(startup)
         # write simple test file, to check that the startup file was run
         with open(self.fname, 'w') as f:
-            f.write(py3compat.doctest_refactor_print(test))
+            f.write(test)
 
     def validate(self, output):
         tt.ipexec_validate(self.fname, output, '', options=self.options)
 
     @dec.skipif(win32_without_pywin32(), "Test requires pywin32 on Windows")
     def test_startup_py(self):
-        self.init('00-start.py', 'zzz=123\n', 
-                  py3compat.doctest_refactor_print('print zzz\n'))
+        self.init('00-start.py', 'zzz=123\n', 'print(zzz)\n')
         self.validate('123')
 
     @dec.skipif(win32_without_pywin32(), "Test requires pywin32 on Windows")
